## Description

<!-- Describe your changes in detail -->

## Type of Change

<!-- Mark the relevant option with an "x" -->

- [ ] `feat`: New feature (triggers minor version bump)
- [ ] `fix`: Bug fix (triggers patch version bump)
- [ ] `perf`: Performance improvement (triggers patch version bump)
- [ ] `docs`: Documentation only changes
- [ ] `style`: Code style changes (formatting, missing semi colons, etc)
- [ ] `refactor`: Code refactoring without functionality changes
- [ ] `test`: Adding or updating tests
- [ ] `chore`: Changes to build process or auxiliary tools
- [ ] `ci`: Changes to CI configuration files and scripts

## Motivation and Context

<!-- Why is this change required? What problem does it solve? -->

## How Has This Been Tested?

<!-- Please describe the tests you ran to verify your changes -->

- [ ] Unit tests pass (`make test-no-pyspark`)
- [ ] PySpark tests pass (`make test-pyspark`)
- [ ] Linting passes (`make lint`)
- [ ] Type checking passes (`make typecheck`)

## Checklist

- [ ] My code follows the code style of this project
- [ ] I have updated the documentation accordingly
- [ ] I have added tests to cover my changes
- [ ] All new and existing tests passed
- [ ] My commit messages follow the [Conventional Commits](https://www.conventionalcommits.org/) specification

## Related Issues

<!-- Link any related issues here. Use "Closes #123" to auto-close issues when merged -->

Closes #
